==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/AzureFileVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AzureFileVolumeSourceBuilder extends AzureFileVolumeSourceFluentImpl<AzureFileVolumeSourceBuilder> implements VisitableBuilder<AzureFileVolumeSource,AzureFileVolumeSourceBuilder>{
  public AzureFileVolumeSourceBuilder() {
    this(false);
  }
  public AzureFileVolumeSourceBuilder(Boolean validationEnabled) {
    this(new AzureFileVolumeSource(), validationEnabled);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AzureFileVolumeSource(), validationEnabled);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance) {
    this(fluent, instance, false);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withSecretName(instance.getSecretName());
      fluent.withShareName(instance.getShareName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance) {
    this(instance,false);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withReadOnly(instance.getReadOnly());
      this.withSecretName(instance.getSecretName());
      this.withShareName(instance.getShareName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AzureFileVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AzureFileVolumeSource build() {
    AzureFileVolumeSource buildable = new AzureFileVolumeSource(fluent.getReadOnly(),fluent.getSecretName(),fluent.getShareName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/AzureFileVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AzureFileVolumeSourceBuilder extends AzureFileVolumeSourceFluent<AzureFileVolumeSourceBuilder> implements VisitableBuilder<AzureFileVolumeSource,AzureFileVolumeSourceBuilder>{
  public AzureFileVolumeSourceBuilder() {
    this(false);
  }
  public AzureFileVolumeSourceBuilder(Boolean validationEnabled) {
    this(new AzureFileVolumeSource(), validationEnabled);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AzureFileVolumeSource(), validationEnabled);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance) {
    this(fluent, instance, false);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AzureFileVolumeSource());

    if (instance != null) {
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withSecretName(instance.getSecretName());
      fluent.withShareName(instance.getShareName());
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withSecretName(instance.getSecretName());
      fluent.withShareName(instance.getShareName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance) {
    this(instance,false);
  }
  public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AzureFileVolumeSource());

    if (instance != null) {
      this.withReadOnly(instance.getReadOnly());
      this.withSecretName(instance.getSecretName());
      this.withShareName(instance.getShareName());
      this.withReadOnly(instance.getReadOnly());
      this.withSecretName(instance.getSecretName());
      this.withShareName(instance.getShareName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AzureFileVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AzureFileVolumeSource build() {
    AzureFileVolumeSource buildable = new AzureFileVolumeSource(fluent.getReadOnly(),fluent.getSecretName(),fluent.getShareName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
